@@ -90,7 +90,7 @@ static volatile boolean_t running = false;
  * message if monit httpd _should_ start but can't.
  */
 boolean_t can_http() {
-        if ((Run.httpd.flags & Httpd_Net || Run.httpd.flags & Httpd_Unix) && Run.isdaemon) {
+        if ((Run.httpd.flags & Httpd_Net || Run.httpd.flags & Httpd_Unix) && (Run.flags & Run_Daemon)) {
                 if (! Engine_hasHostsAllow() && ! Run.httpd.credentials) {
                         LogError("%s: monit httpd not started since no connect allowed\n", prog);
                         return false;
@@ -137,9 +137,6 @@ void monit_http(Httpd_Action action) {
 
 
 static void *thread_wrapper(void *arg) {
-        sigset_t ns;
-        /* Block collective signals in the http thread. The http server is taken down gracefully by signaling the main monit thread */
-        set_signal_block(&ns, NULL);
         Engine_start();
 #ifdef HAVE_OPENSSL
         Ssl_threadCleanup();
