@@ -121,7 +121,7 @@ static void log_backtrace();
  * @return true if the log system was successfully initialized
  */
 boolean_t log_init() {
-        if (! Run.dolog)
+        if (! (Run.flags & Run_Log))
                 return true;
         if (! open_log())
                 return false;
@@ -289,7 +289,7 @@ void LogDebug(const char *s, ...) {
  */
 void log_close() {
 
-        if (Run.use_syslog) {
+        if (Run.flags & Run_UseSyslog) {
                 closelog();
         }
 
@@ -322,12 +322,12 @@ void vsyslog (int facility_priority, const char *format, va_list arglist) {
  */
 static boolean_t open_log() {
 
-        if (Run.use_syslog) {
+        if (Run.flags & Run_UseSyslog) {
                 openlog(prog, LOG_PID, Run.facility);
         } else {
-                LOG = fopen(Run.logfile, "a+");
+                LOG = fopen(Run.files.log, "a+");
                 if (! LOG) {
-                        LogError("Error opening the log file '%s' for writing -- %s\n", Run.logfile, STRERROR);
+                        LogError("Error opening the log file '%s' for writing -- %s\n", Run.files.log, STRERROR);
                         return false;
                 }
                 /* Set logger in unbuffered mode */
@@ -404,8 +404,8 @@ static void log_log(int priority, const char *s, va_list ap) {
 #endif
                 fflush(output);
 
-                if (Run.dolog) {
-                        if (Run.use_syslog) {
+                if (Run.flags & Run_Log) {
+                        if (Run.flags & Run_UseSyslog) {
 #ifdef HAVE_VA_COPY
                                 va_copy(ap_copy, ap);
                                 vsyslog(priority, s, ap_copy);
